@@ -1,4 +1,4 @@
-/* $Id: python.c,v 1.32 2004/02/14 17:55:23 wojtekka Exp $ */
+/* $Id: python.c,v 1.34 2005/06/07 19:58:56 porridge Exp $ */
 
 /*
  *  (C) Copyright 2002-2003 Wojtek Kaniewski <wojtekka@irc.pl>
@@ -24,12 +24,10 @@
 #include <sys/stat.h>
 
 #include <dirent.h>
-#include <Python.h>
 #include <string.h>
 
 #include "commands.h"
 #include "libgadu.h"
-#include "python.h"
 #include "stuff.h"
 #include "themes.h"
 #include "ui.h"
@@ -37,6 +35,9 @@
 #include "version.h"
 #include "xmalloc.h"
 
+#include <Python.h>
+#include "python.h"
+
 int python_handle_result = -1;
 
 static PyObject* ekg_cmd_connect(PyObject *self, PyObject *args)
@@ -225,7 +226,12 @@ int python_initialize()
 	/* PyImport_ImportModule spodziewa si nazwy moduu, ktry znajduje
 	 * si w $PYTHONPATH, wic dodajemy tam katalog ~/.gg/scripts. mona
 	 * to zrobi w bardziej elegancki sposb, ale po co komplikowa sobie
-	 * ycie? */
+	 * ycie?
+	 *
+	 * Argument putenv() nie jest zwalniany xfree(), bo powoduje to
+	 * problemy na systemach, w ktrych putenv() jest zgodne z SUSv2 (np
+	 * niektre SunOS).
+	 */
 
 	if (getenv("PYTHONPATH")) {
 		char *tmp = saprintf("%s:%s", getenv("PYTHONPATH"), prepare_path("scripts", 0));
@@ -235,7 +241,6 @@ int python_initialize()
 		{
 			char *s = saprintf("PYTHONPATH=%s", tmp);
 			putenv(s);
-			xfree(s);
 		}
 #endif
 		xfree(tmp);
@@ -246,7 +251,6 @@ int python_initialize()
 		{
 			char *s = saprintf("PYTHONPATH=%s", prepare_path("scripts", 0));
 			putenv(s);
-			xfree(s);
 		}
 #endif
 	}
