@@ -1,12 +1,13 @@
-/* $Id: stuff.c,v 1.420 2004/06/19 20:43:44 szalik Exp $ */
+/* $Id: stuff.c,v 1.442 2005/09/19 21:01:21 szalik Exp $ */
 
 /*
- *  (C) Copyright 2001-2003 Wojtek Kaniewski <wojtekka@irc.pl>
+ *  (C) Copyright 2001-2005 Wojtek Kaniewski <wojtekka@irc.pl>
  *                          Robert J. Wony <speedy@ziew.org>
  *                          Pawe Maziarz <drg@o2.pl>
  *                          Dawid Jarosz <dawjar@poczta.onet.pl>
  *                          Piotr Domagalski <szalik@szalik.net>
  *                          Piotr Kupisiewicz <deli@rzepaknet.us>
+ *                          Adam Wysocki <gophi@ekg.apcoh.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License Version 2 as
@@ -91,6 +92,7 @@ list_t conferences = NULL;
 list_t sms_away = NULL;
 list_t buffers = NULL;
 list_t searches = NULL;
+list_t spiedlist = NULL;
 
 int command_processing = 0;
 int in_autoexec = 0;
@@ -111,6 +113,7 @@ int config_beep_notify = 1;
 int config_beep_mail = 1;
 int config_display_pl_chars = 1;
 int config_events_delay = 3;
+int config_era_omnix = 0;
 char *config_sound_msg_file = NULL;
 char *config_sound_chat_file = NULL;
 char *config_sound_sysmsg_file = NULL;
@@ -139,8 +142,10 @@ int config_status = GG_STATUS_AVAIL;
 char *reg_password = NULL;
 char *reg_email = NULL;
 int config_dcc = 0;
+int config_dcc_backups = 0;
 char *config_dcc_ip = NULL;
 char *config_dcc_dir = NULL;
+int config_dcc_port = GG_DEFAULT_DCC_PORT;
 char *config_reason = NULL;
 char *home_dir = NULL;
 char *config_quit_reason = NULL;
@@ -183,6 +188,7 @@ int config_windows_save = 0;
 char *config_windows_layout = NULL;
 char *config_profile = NULL;
 int config_header_size = 0;
+int config_status_window = 0;
 int config_statusbar_size = 1;
 int config_statusbar_fgcolor = 7;
 int config_statusbar_bgcolor = 4;
@@ -192,6 +198,7 @@ char *config_interface = NULL;
 int config_reason_limit = 0;
 char *config_dcc_limit = NULL;
 int config_ignore_unknown_sender = 0;
+int config_ignore_empty_msg = 0;
 #ifdef WITH_WAP
 int config_wap_enabled = 2;
 #endif
@@ -202,6 +209,7 @@ int config_display_token = 1;
 int config_ioctld_enable = 1;
 int config_ioctld_net_port = 22004;
 #endif
+int config_dcc_filter = 1;
 
 char *last_search_first_name = NULL;
 char *last_search_last_name = NULL;
@@ -229,6 +237,9 @@ struct event_label event_labels[EVENT_LABELS_COUNT + 2] = {
 	{ EVENT_NEWMAIL, "newmail" },
 	{ EVENT_BLOCKED, "blocked" },
 	{ EVENT_DCCFINISH, "dccfinish" },
+	{ EVENT_CONNECTED, "connected" },
+	{ EVENT_DISCONNECTED, "disconnected" },
+	{ EVENT_CONNECTIONLOST, "connectionlost" },
 
 	{ INACTIVE_EVENT, NULL },
 	{ 0, NULL }
@@ -296,8 +307,10 @@ int alias_add(const char *string, int quiet, int append)
 			return -1;
 		}
 
-		if (!strncasecmp(tmp, c->name, strlen(c->name)))
+		if (!strncasecmp(tmp, c->name, strlen(c->name))) {
 			params = xstrdup(c->params);
+			break;
+		}
 	}
 
 	a.name = xstrdup(string);
@@ -643,8 +656,11 @@ void changed_auto_save(const char *var)
 #ifdef WITH_ASPELL
 void changed_aspell(const char *var)
 {
-	/* probujemy zainicjowac jeszcze raz aspell'a */
-	spellcheck_init();
+	if (config_aspell == 1) {
+		spellcheck_init();
+	} else {
+		spellcheck_deinit();
+	}
 }
 #endif
 
@@ -691,7 +707,7 @@ void changed_dcc(const char *var)
 		}
 	
 		if (config_dcc && !dcc) {
-			if (!(dcc = gg_dcc_socket_create(config_uin, 0))) {
+			if (!(dcc = gg_dcc_socket_create(config_uin, config_dcc_port))) {
 				print("dcc_create_error", strerror(errno));
 			} else {
 				list_add(&watches, dcc, 0);
@@ -716,6 +732,44 @@ void changed_dcc(const char *var)
 		} else
 			gg_dcc_ip = 0;
 	}
+
+	if (!strcmp(var, "dcc_port")) {
+		for (l = watches; l; l = l->next) {
+			struct gg_common *c = l->data;
+	
+			if (c->type == GG_SESSION_DCC_SOCKET)
+				dcc = l->data;
+		}
+		
+		if (config_dcc && dcc && (dcc->port != config_dcc_port)) {
+			list_remove(&watches, dcc, 0);
+			gg_free_dcc(dcc);
+			gg_dcc_ip = 0;
+			gg_dcc_port = 0;
+		
+			if (!(dcc = gg_dcc_socket_create(config_uin, config_dcc_port))) {
+				print("dcc_create_error", strerror(errno));
+			} else {
+				list_add(&watches, dcc, 0);
+			}
+		}
+	}
+
+	if (sess && sess->state == GG_STATE_CONNECTED)
+		print("dcc_must_reconnect");
+	
+	update_status_myip();
+}
+
+/*
+ * changed_era_omnix() 
+ *
+ * funkcja wywoywana przy zmianie wartoci zmiennej ,,era_omnix''.
+ */
+void changed_era_omnix(const char *var)
+{
+	if (sess && sess->state == GG_STATE_CONNECTED)
+		print("dcc_must_reconnect");
 }
 
 /*
@@ -858,7 +912,7 @@ void changed_xxx_reason(const char *var)
 		print("descr_too_long", itoa(strlen(tmp) - GG_STATUS_DESCR_MAXSIZE));
 }
 
-const char *compile_time()
+const char *compile_time(void)
 {
 	return __DATE__ " " __TIME__;
 }
@@ -876,7 +930,7 @@ const char *compile_time()
  */
 struct conference *conference_add(const char *name, const char *nicklist, int quiet)
 {
-	struct conference c;
+	struct conference c, *ret;
 	char **nicks, **p;
 	list_t l;
 	int i, count;
@@ -933,8 +987,8 @@ struct conference *conference_add(const char *name, const char *nicklist, int qu
 				array_free(nicks);
 				return NULL;
 			}
-			xfree(gname);
 
+			xfree(gname);
 		}
 	}
 
@@ -954,15 +1008,31 @@ struct conference *conference_add(const char *name, const char *nicklist, int qu
 
 	for (p = nicks, i = 0; *p; p++) {
 		uin_t uin;
+		list_t l;
 
 		if (!strcmp(*p, ""))
 		        continue;
-	
+
 		if (!(uin = get_uin(*p))) {
 			printq("user_not_found", *p);
-			continue;
+			break;
 		}
 
+		if (uin == config_uin)
+			break;
+
+		for (l = c.recipients; l; l = l->next) {
+			uin_t tmp = *((uin_t *)l->data);
+
+			if (tmp == uin) {
+				uin = 0;
+				break;
+			}
+		}
+
+		if (!uin)
+			break;
+
 		list_add(&(c.recipients), &uin, sizeof(uin));
 		i++;
 	}
@@ -971,6 +1041,8 @@ struct conference *conference_add(const char *name, const char *nicklist, int qu
 
 	if (i != count) {
 		printq("conferences_not_added", name);
+		if (c.recipients)
+			list_destroy(c.recipients, 1);
 		return NULL;
 	}
 
@@ -980,9 +1052,26 @@ struct conference *conference_add(const char *name, const char *nicklist, int qu
 
 	add_send_nick(name);
 
-	event_check(EVENT_CONFERENCE, 1, name);
+	ret = list_add(&conferences, &c, sizeof(c));
 
-	return list_add(&conferences, &c, sizeof(c));
+	event_check(EVENT_CONFERENCE, 0, name);
+
+	/* jeli na licie zdarze jest usunicie konferencji, to ret ju nie 
+	 * wskazuje na nic sensownego. nie tworzymy konferencji. moe troch 
+	 * mao eleganckie rozwizanie, ale nie przychodzi mi do gowy nic 
+	 * lepszego. -- gophi */
+
+	{
+		list_t cur = conferences;
+
+		while (cur) {
+			if ((void *) ret == cur->data)
+				return ret;
+			cur = cur->next;
+		}
+	}
+
+	return (struct conference *) NULL;
 }
 
 /*
@@ -1278,6 +1367,7 @@ void ekg_connect()
 	p.has_audio = 1;
 #endif
 	p.protocol_version = config_protocol;
+	p.era_omnix = config_era_omnix;
 	p.last_sysmsg = config_last_sysmsg;
 
 	if (config_server) {
@@ -1500,15 +1590,15 @@ int event_add(int flags, const char *target, const char *action, int quiet)
 	}
 
 	e.name = xstrdup(itoa(f));
-        e.target = xstrdup(target);
-        e.flags = flags;
-        e.action = xstrdup(action);
+	e.target = xstrdup(target);
+	e.flags = flags;
+	e.action = xstrdup(action);
 
-        list_add(&events, &e, sizeof(e));
+	list_add(&events, &e, sizeof(e));
 
 	printq("events_add", e.name);
 
-        return 0;
+	return 0;
 }
 
 /*
@@ -1556,6 +1646,16 @@ int event_remove(const char *name, int quiet)
 	} else {
 		if (remove_all)
 			printq("events_del_all");
+		else {
+			int num = 1;
+
+			for (l = events; l; l = l->next) {
+				struct event *e = l->data;
+
+				xfree(e->name);
+				e->name = xstrdup(itoa(num++));
+			}
+		}
 
 		return 0;
 	}
@@ -1686,7 +1786,7 @@ int event_check(int event, uin_t uin, const char *data)
 		
                 if (e->flags & event) {
 
-			if (!strcmp(e->target, "*") || uin == 1)
+			if (!strcmp(e->target, "*") || uin == 0)
 				action = e->action;
 
 			if (!strcmp(e->target, uin_number) || !strcasecmp(e->target, uin_display) || (u && group_member(u, e->target + 1))) {
@@ -1763,7 +1863,9 @@ void event_free()
 	for (l = events; l; l = l->next) {
 		struct event *e = l->data;
 
+		xfree(e->name);
 		xfree(e->action);
+		xfree(e->target);
 	}
 
 	list_destroy(events, 1);
@@ -1928,14 +2030,14 @@ void iso_to_ascii(unsigned char *buf)
 /*
  * strip_chars()
  *
- * pozbywa si podanego znaku na pocztku i kocu ancucha
+ * pozbywa si podanego znaku na pocztku i kocu ancucha.
  */
 char *strip_chars(char *line, unsigned char what)
 {
 	while (*line == what)
 		line++;
 
-        if (line[strlen(line) - 1] == what)
+        while (strlen(line) > 1 && line[strlen(line) - 1] == what)
         	line[strlen(line) - 1] = 0;
 
         return line;
@@ -2035,7 +2137,7 @@ int process_remove(int pid)
  */
 const char *prepare_path(const char *filename, int do_mkdir)
 {
-	static char path[PATH_MAX];
+	static char path[PATH_MAX + 1];
 
 	if (do_mkdir) {
 		if (config_profile) {
@@ -2737,7 +2839,7 @@ void update_status()
 		return;
 
 	if ((u->descr && config_reason && strcmp(u->descr, config_reason)) || (!u->descr && config_reason) || (u->descr && !config_reason))
-		event_check(EVENT_DESCR, config_uin, u->descr);
+		event_check(EVENT_DESCR, config_uin, config_reason);
 
 	xfree(u->descr);
 	u->descr = xstrdup(config_reason);
@@ -2771,7 +2873,7 @@ void update_status_myip()
 	if (!sess || sess->state != GG_STATE_CONNECTED)
 		goto fail;
 	
-	if (config_dcc && config_dcc_ip) {
+	if (config_dcc && config_dcc_ip && config_dcc_port) {
 		list_t l;
 
 		if (strcmp(config_dcc_ip, "auto"))
