@@ -1,11 +1,12 @@
-/* $Id: stuff.h,v 1.246 2004/06/19 19:25:33 deletek Exp $ */
+/* $Id: stuff.h,v 1.269 2005/10/09 10:50:15 szalik Exp $ */
 
 /*
- *  (C) Copyright 2001-2003 Wojtek Kaniewski <wojtekka@irc.pl>
+ *  (C) Copyright 2001-2005 Wojtek Kaniewski <wojtekka@irc.pl>
  *                          Robert J. Wony <speedy@ziew.org>
  *                          Pawe Maziarz <drg@go2.pl>
  *                          Dawid Jarosz <dawjar@poczta.onet.pl>
  *                          Piotr Domagalski <szalik@szalik.net>
+ *                          Adam Wysocki <gophi@ekg.apcoh.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License Version 2 as
@@ -41,6 +42,8 @@
 
 #define TOGGLE_BIT(x) (1 << (x - 1))
 
+#define SPYING_RESPONSE_TIMEOUT 15
+
 enum event_t {
 	EVENT_MSG = TOGGLE_BIT(1),
 	EVENT_CHAT = TOGGLE_BIT(2),
@@ -60,19 +63,22 @@ enum event_t {
 	EVENT_NEWMAIL = TOGGLE_BIT(16),
 	EVENT_BLOCKED = TOGGLE_BIT(17),
 	EVENT_DCCFINISH = TOGGLE_BIT(18),
+	EVENT_CONNECTED = TOGGLE_BIT(19),
+	EVENT_DISCONNECTED = TOGGLE_BIT(20),
+	EVENT_CONNECTIONLOST = TOGGLE_BIT(21),
 
-	EVENT_ALL = TOGGLE_BIT(19) - 1,
-	INACTIVE_EVENT = TOGGLE_BIT(19)
+	EVENT_ALL = TOGGLE_BIT(22) - 1,
+	INACTIVE_EVENT = TOGGLE_BIT(22)
 };
 
-#define EVENT_LABELS_COUNT 18	/* uaktualni ! */
-struct event_label event_labels[EVENT_LABELS_COUNT + 2];
-
 struct event_label {
 	int event;
 	char *name;
 };
 
+#define EVENT_LABELS_COUNT 21	/* uaktualni ! */
+struct event_label event_labels[EVENT_LABELS_COUNT + 2];
+
 struct process {
 	int pid;		/* id procesu */
 	int died;		/* proces umar, ale najpierw pobieramy do koca z bufora dane */
@@ -90,6 +96,7 @@ struct transfer {
 	uin_t uin;
 	char *filename;
 	struct gg_dcc *dcc;
+	time_t start;
 	int type;
 	int id;
 	int protocol;
@@ -139,6 +146,12 @@ struct timer {
 	char *id;
 };
 
+struct spied {
+	uin_t uin;
+	int timeout;
+	struct timeval request_sent;
+};
+
 struct sms_away {
 	uin_t uin;
 	int count;
@@ -188,6 +201,7 @@ list_t conferences;
 list_t sms_away;
 list_t buffers;
 list_t searches;
+list_t spiedlist;
 
 struct gg_session *sess;
 
@@ -230,9 +244,12 @@ char *config_contacts_options;
 int config_contacts_size;
 int config_ctrld_quits;
 int config_dcc;
+int config_dcc_backups;
 char *config_dcc_ip;
 char *config_dcc_dir;
+int config_dcc_filter;
 char *config_dcc_limit;
+int config_dcc_port;
 int config_display_ack;
 int config_display_color;
 char *config_display_color_map;
@@ -250,9 +267,11 @@ int config_emoticons;
 int config_encryption;
 int config_enter_scrolls;
 int config_events_delay;
+int config_era_omnix;
 char *config_interface;
 int config_header_size;
 int config_ignore_unknown_sender;
+int config_ignore_empty_msg;
 int config_irssi_set_mode;
 int config_keep_reason;
 int config_last;
@@ -295,6 +314,7 @@ char *config_sound_notify_file;
 char *config_sound_mail_file;
 char *config_speech_app;
 int config_status;
+int config_status_window;
 int config_statusbar_size;
 int config_statusbar_fgcolor;
 int config_statusbar_bgcolor;
@@ -324,6 +344,7 @@ time_t last_conn_event;
 time_t ekg_started;
 int server_index;
 int in_auto_away;
+int quit_command;
 
 int use_proxy;
 int proxy_port;
@@ -369,6 +390,7 @@ void changed_aspell(const char *var);
 #endif
 void changed_backlog_size(const char *var);
 void changed_dcc(const char *var);
+void changed_era_omnix(const char *var);
 void changed_local_ip(const char *var);
 void changed_mesg(const char *var);
 void changed_proxy(const char *var);
@@ -376,7 +398,7 @@ void changed_theme(const char *var);
 void changed_uin(const char *var);
 void changed_xxx_reason(const char *var);
 
-const char *compile_time();
+const char *compile_time(void);
 
 struct conference *conference_add(const char *string, const char *nicklist, int quiet);
 int conference_remove(const char *name, int quiet);
@@ -462,9 +484,12 @@ int ekg_hide_descr_status(int status);
 /* funkcje poza stuff.c */
 void ekg_wait_for_key();
 void ekg_exit();
+int check_conn(uin_t uin);
+void save_windows();
 
 #ifdef WITH_ASPELL
 void spellcheck_init(void);
+void spellcheck_deinit(void);
 #endif
 
 #endif /* __STUFF_H */
