@@ -1,8 +1,9 @@
-/* $Id: themes.c,v 1.318 2004/04/28 09:12:49 wojtekka Exp $ */
+/* $Id: themes.c,v 1.332 2005/09/14 23:54:13 gophi Exp $ */
 
 /*
- *  (C) Copyright 2001-2002 Wojtek Kaniewski <wojtekka@irc.pl>
+ *  (C) Copyright 2001-2005 Wojtek Kaniewski <wojtekka@irc.pl>
  * 			    Piotr Kupisiewicz <deli@rzepaknet.us>
+ *                          Adam Wysocki <gophi@ekg.apcoh.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License Version 2 as
@@ -682,7 +683,7 @@ int format_remove(const char *name)
  */
 static FILE *try_open(FILE *prevfd, const char *prefix, const char *filename)
 {
-	char buf[PATH_MAX];
+	char buf[PATH_MAX + 1];
 	int save_errno;
 	FILE *f;
 
@@ -915,7 +916,7 @@ void theme_init()
 	format_add("help", "%> %T%1%n%2 - %3\n", 1);
 	format_add("help_more", "%) %|%1\n", 1);
 	format_add("help_alias", "%) %T%1%n jest aliasem i nie posiada opisu\n", 1);
-	format_add("help_footer", "\n%> %|Wicej szczegw na temat komend zwrci %Thelp <komenda>%n. Poprzedzenie komendy znakiem %T^%n spowoduje ukrycie jej wyniku. Zamiast parametru <numer/alias> mona uy znaku %T$%n oznaczajcego aktualnego rozmwc.\n\n", 1);
+	format_add("help_footer", "\n%> %|Wicej szczegw na temat komend zwrci %Thelp <komenda>%n. Opis zmiennych mona otrzyma wpisujc %Thelp set <zmienna>%n. Poprzedzenie komendy znakiem %T^%n spowoduje ukrycie jej wyniku. Zamiast parametru <numer/alias> mona uy znaku %T$%n oznaczajcego aktualnego rozmwc.\n\n", 1);
 	format_add("help_quick", "%> %|Przed uyciem przeczytaj ulotk. Plik %Tdocs/ULOTKA%n zawiera krtki przewodnik po zaczonej dokumentacji. Jeli go nie masz, moesz cign pakiet ze strony %Thttp://dev.null.pl/ekg/%n\n", 1);
 	format_add("help_set_file_not_found", "%! Nie znaleziono opisu zmiennych (nieprawidowa instalacja)\n", 1);
 	format_add("help_set_var_not_found", "%! Nie znaleziono opisu zmiennej %T%1%n\n", 1);
@@ -957,6 +958,8 @@ void theme_init()
 	format_add("modify_online", "%> %1 bdzie widzie nasz stan\n", 1);
 	format_add("modify_done", "%> Zmieniono wpis w licie kontaktw\n", 1);
 
+	format_add("tab_cleared", "%> Wyczyszczono list nickw do dopenienia", 1);
+
 	/* lista kontaktw z boku ekranu */
 	format_add("contacts_header", "", 1);
 	format_add("contacts_header_group", "%K %1%n", 1);
@@ -1042,6 +1045,7 @@ void theme_init()
 	format_add("ack_queued", "%> Wiadomo do %1 zostanie dostarczona pniej\n", 1);
 	format_add("ack_delivered", "%> Wiadomo do %1 zostaa dostarczona\n", 1);
 	format_add("ack_filtered", "%! %|Wiadomo do %1 najprawdopodobniej nie zostaa dostarczona, poniewa dana osoba jest niedostpna, a serwer twierdzi, e dorczy wiadomo. Sytuacja taka ma miejsce, gdy wiadomo zostaa odrzucona przez filtry serwera (np. zawiera adres strony WWW)\n", 1);
+	format_add("ack_filtered_short", "%! %|Wiadomo do %1 najprawdopodobniej nie zostaa dostarczona\n", 1);
 	format_add("message_too_long", "%! Wiadomo jest zbyt duga i zostaa skrcona\n", 1);
 
 	/* ludzie zmieniaj stan */
@@ -1053,6 +1057,7 @@ void theme_init()
 	format_add("status_not_avail_descr", "%> %1 jest niedostpn%@2: %T%3%n\n", 1);
 	format_add("status_invisible", "%> %1 jest niewidoczn%@2\n", 1);
 	format_add("status_invisible_descr", "%> %1 jest niewidoczn%@2: %T%3%n\n", 1);
+	format_add("user_is_connected", "%> %1 jest poczon%@2 z serwerem%n\n", 1);
 
 	format_add("auto_away", "%> Automagicznie zmieniono stan na zajty po %1 nieaktywnoci\n", 1);
 	format_add("auto_away_descr", "%> Automagicznie zmieniono stan na zajty po %1 nieaktywnoci: %T%2%n%3\n", 1);
@@ -1199,6 +1204,7 @@ void theme_init()
 	format_add("user_info_last_descr", "%K| %nOstatni opis: %T%1%n\n", 1);
 	format_add("user_info_version", "%K| %nWersja klienta: %T%1%n\n", 1);
 	format_add("user_info_voip", "%K| %nObsuguje rozmowy gosowe\n", 1);
+	format_add("user_info_era_omnix", "%K| %nPoczony przez bramk Era Omnix\n", 1);
 	format_add("user_info_last_ip","%K| %nOstatni adres IP: %T%1%n\n", 1);
 	format_add("user_info_footer", "%K`----- ---- --- -- -%n\n", 1);
 
@@ -1276,7 +1282,11 @@ void theme_init()
 	format_add("dcc_show_pending_voice", "%) #%1, %2, rozmowa\n", 1);
 	format_add("dcc_show_active_header", "%> Poczenia aktywne:\n", 1);
 	format_add("dcc_show_active_send", "%) #%1, %2, wysyanie %T%3%n, %T%4b%n z %T%5b%n (%6%%)\n", 1);
+	format_add("dcc_show_active_send_speed_s", "%) #%1, %2, wysyanie %T%3%n, %T%4b%n z %T%5b%n (%6%%, %T%7%nkB/s, pozostao %T%8%ns)\n", 1);
+	format_add("dcc_show_active_send_speed_ms", "%) #%1, %2, wysyanie %T%3%n, %T%4b%n z %T%5b%n (%6%%, %T%7%nkB/s, pozostao %T%8%nm %T%9%ns)\n", 1);
 	format_add("dcc_show_active_get", "%) #%1, %2, odbir %T%3%n, %T%4b%n z %T%5b%n (%6%%)\n", 1);
+	format_add("dcc_show_active_get_speed_s", "%) #%1, %2, odbir %T%3%n, %T%4b%n z %T%5b%n (%6%%, %T%7%nkB/s, pozostao %T%8%ns)\n", 1);
+	format_add("dcc_show_active_get_speed_ms", "%) #%1, %2, odbir %T%3%n, %T%4b%n z %T%5b%n (%6%%, %T%7%nkB/s, pozostao %T%8%nm %T%9%ns)\n", 1);
 	format_add("dcc_show_active_voice", "%) #%1, %2, rozmowa\n", 1);
 	format_add("dcc_show_empty", "%! Brak bezporednich pocze\n", 1);
 	format_add("dcc_receiving_already", "%! Plik %T%1%n od uytkownika %2 jest ju pobierany\n", 1);
@@ -1292,9 +1302,12 @@ void theme_init()
 	format_add("dcc_get_offer_resume", "%) Plik istnieje ju na dysku, wic mona wznowi pobieranie poleceniem %Tdcc resume #%4%n\n", 1);
 	format_add("dcc_get_getting", "%) Rozpoczto pobieranie pliku %T%2%n od %1\n", 1);
 	format_add("dcc_get_cant_create", "%! Nie mona utworzy pliku %T%1%n\n", 1);
+	format_add("dcc_get_backup_made", "%) Plik %T%1%n istnieje. Pobierany plik zostanie zapisany jako %T%2%n\n", 1);
+	format_add("dcc_get_cant_overwrite", "%! Plik %T%1%n i wszystkie jego kopie istniej\n", 1);
 	format_add("dcc_not_found", "%! Nie znaleziono poczenia %T%1%n\n", 1);
 	format_add("dcc_invalid_ip", "%! Nieprawidowy adres IP\n", 1);
-	format_add("dcc_user_not_avail", "%! %1 musi by aktywn%@1, by mc nawiza poczenie\n", 1);
+	format_add("dcc_user_not_avail", "%! %1 musi by aktywn%@2, by mc nawiza poczenie\n", 1);
+	format_add("dcc_must_reconnect", "%) Aby zmiany odniosy skutek, naley ponownie poczy si z serwerem\n", 1);
 
 	/* query */
 	format_add("query_started", "%) Rozpoczto rozmow z %T%1%n\n", 1);
@@ -1400,7 +1413,7 @@ void theme_init()
 	/* conference */
 	format_add("conferences_list_empty", "%! Brak konferencji\n", 1);
 	format_add("conferences_list", "%> %T%1%n: %2\n", 1);
-	format_add("conferences_list_ignored", "%> %T%1%n: %2 (%yingorowana%n)\n", 1);
+	format_add("conferences_list_ignored", "%> %T%1%n: %2 (%yignorowana%n)\n", 1);
 	format_add("conferences_add", "%> Utworzono konferencj %T%1%n\n", 1);
 	format_add("conferences_not_added", "%! Nie utworzono konferencji %T%1%n\n", 1);
 	format_add("conferences_del", "%) Usunito konferencj %T%1%n\n", 1);
@@ -1448,4 +1461,11 @@ void theme_init()
 	format_add("python_not_found", "%! Nie znaleziono skryptu %T%1%n\n", 1);
 	format_add("python_wrong_location", "%! Skrypt naley umieci w katalogu %T%1%n\n", 1);
 #endif
+
+#ifdef WITH_ASPELL
+	/* aspell */
+	format_add("aspell_init", "%> Czekaj, inicjuj modu sprawdzania pisowni...\n", 1);
+	format_add("aspell_init_success", "%> Zainicjowano modu sprawdzania pisowni\n", 1);
+	format_add("aspell_init_error", "%! Bd moduu sprawdzania pisowni: %T%1%n\n", 1);
+#endif
 }
