@@ -1,8 +1,9 @@
-/* $Id: vars.c,v 1.164 2004/02/26 23:12:37 deletek Exp $ */
+/* $Id: vars.c,v 1.178 2005/07/29 18:13:28 szalik Exp $ */
 
 /*
- *  (C) Copyright 2001-2003 Wojtek Kaniewski <wojtekka@irc.pl>
+ *  (C) Copyright 2001-2005 Wojtek Kaniewski <wojtekka@irc.pl>
  *                          Robert J. Wony <speedy@ziew.org>
+ *                          Adam Wysocki <gophi@ekg.apcoh.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License Version 2 as
@@ -105,6 +106,8 @@ void variable_init()
 	variable_add("email", "em", VAR_STR, 1, &config_email, NULL, NULL, NULL);
 #ifdef HAVE_VOIP
 	variable_add("audio_device", "ad", VAR_STR, 1, &config_audio_device, NULL, NULL, NULL);
+#else
+	variable_add("audio_device", "ad", VAR_STR, 2, NULL, NULL, NULL, NULL);
 #endif
 	variable_add("auto_away", "aa", VAR_INT, 1, &config_auto_away, NULL, NULL, NULL);
 	variable_add("auto_away_keep_descr", "ak", VAR_BOOL, 1, &config_auto_away_keep_descr, NULL, NULL, NULL);
@@ -117,25 +120,49 @@ void variable_init()
 	variable_add("aspell", "al", VAR_BOOL, 1, &config_aspell, changed_aspell, NULL, NULL);
 	variable_add("aspell_lang", "ag", VAR_STR, 1, &config_aspell_lang, changed_aspell, NULL, NULL);
 	variable_add("aspell_encoding", "an", VAR_STR, 1, &config_aspell_encoding, changed_aspell, NULL, NULL);
+#else
+	variable_add("aspell", "al", VAR_BOOL, 2, NULL, NULL, NULL, NULL);
+	variable_add("aspell_lang", "ag", VAR_STR, 2, NULL, NULL, NULL, NULL);
+	variable_add("aspell_encoding", "an", VAR_STR, 2, NULL, NULL, NULL, NULL);
 #endif
 	variable_add("away_reason", "ar", VAR_STR, 1, &config_away_reason, changed_xxx_reason, NULL, NULL);
 	variable_add("back_reason", "br", VAR_STR, 1, &config_back_reason, changed_xxx_reason, NULL, NULL);
 #ifdef WITH_UI_NCURSES
-	if (ui_init == ui_ncurses_init)
+	if (ui_init == ui_ncurses_init) {
+		variable_add("backlog_overlap", "bo", VAR_INT, 1, &config_backlog_overlap, NULL, NULL, NULL);
 		variable_add("backlog_size", "bs", VAR_INT, 1, &config_backlog_size, changed_backlog_size, NULL, NULL);
+	} else {
+		variable_add("backlog_overlap", "bo", VAR_INT, 2, NULL, NULL, NULL, NULL);
+		variable_add("backlog_size", "bs", VAR_INT, 2, NULL, NULL, NULL, NULL);
+	}
+#else
+	variable_add("backlog_overlap", "bo", VAR_INT, 2, NULL, NULL, NULL, NULL);
+	variable_add("backlog_size", "bs", VAR_INT, 2, NULL, NULL, NULL, NULL);
 #endif
 	variable_add("beep", "be", VAR_BOOL, 1, &config_beep, NULL, NULL, NULL);
 	variable_add("beep_msg", "bm", VAR_BOOL, 1, &config_beep_msg, NULL, NULL, dd_beep);
 	variable_add("beep_chat", "bc", VAR_BOOL, 1, &config_beep_chat, NULL, NULL, dd_beep);
 	variable_add("beep_notify", "bn", VAR_BOOL, 1, &config_beep_notify, NULL, NULL, dd_beep);
 	variable_add("beep_mail", "bM", VAR_BOOL, 1, &config_beep_mail, NULL, NULL, dd_beep);
+#ifdef WITH_UI_NCURSES
+	if (ui_init == ui_ncurses_init)
+		variable_add("beep_title", "bt", VAR_INT, 1, &config_beep_title, NULL, NULL, NULL);
+	else
+		variable_add("beep_title", "bt", VAR_INT, 2, NULL, NULL, NULL, NULL);
+#else
+	variable_add("beep_title", "bt", VAR_INT, 2, NULL, NULL, NULL, NULL);
+#endif
 	variable_add("check_mail", "cm", VAR_MAP, 1, &config_check_mail, changed_check_mail, variable_map(4, 0, 0, "no", 1, 2, "mbox", 2, 1, "maildir", 4, 0, "notify"), NULL);
 	variable_add("check_mail_frequency", "cf", VAR_INT, 1, &config_check_mail_frequency, changed_check_mail, NULL, dd_check_mail);
 	variable_add("check_mail_folders", "cF", VAR_STR, 1, &config_check_mail_folders, changed_check_mail_folders, NULL, dd_check_mail);
-	variable_add("completion_notify", "cn", VAR_MAP, 1, &config_completion_notify, NULL, variable_map(4, 0, 0, "none", 1, 2, "add", 2, 1, "addremove", 4, 0, "busy"), NULL);
+	variable_add("completion_notify", "cn", VAR_MAP, 1, &config_completion_notify, NULL, variable_map(5, 0, 0, "none", 1, 2, "add", 2, 1, "addremove", 4, 0, "busy", 8, 0, "invisible"), NULL);
 #ifdef WITH_UI_READLINE
 	if (ui_init == ui_readline_init)
 		variable_add("ctrld_quits", "cq", VAR_BOOL, 1, &config_ctrld_quits, NULL, NULL, NULL);
+	else
+		variable_add("ctrld_quits", "cq", VAR_BOOL, 2, NULL, NULL, NULL, NULL);
+#else
+	variable_add("ctrld_quits", "cq", VAR_BOOL, 2, NULL, NULL, NULL, NULL);
 #endif
 #ifdef WITH_UI_NCURSES
 	if (ui_init == ui_ncurses_init) {
@@ -143,51 +170,86 @@ void variable_init()
 		variable_add("contacts_groups", "cg", VAR_STR, 1, &config_contacts_groups, NULL, NULL, dd_contacts);
 		variable_add("contacts_options", "cO", VAR_STR, 1, &config_contacts_options, NULL, NULL, dd_contacts);
 		variable_add("contacts_size", "cs", VAR_INT, 1, &config_contacts_size, NULL, NULL, dd_contacts);
+	} else {
+		variable_add("contacts", "co", VAR_INT, 2, NULL, NULL, NULL, NULL);
+		variable_add("contacts_groups", "cg", VAR_STR, 2, NULL, NULL, NULL, NULL);
+		variable_add("contacts_options", "cO", VAR_STR, 2, NULL, NULL, NULL, NULL);
+		variable_add("contacts_size", "cs", VAR_INT, 2, NULL, NULL, NULL, NULL);
 	}
+#else
+	variable_add("contacts", "co", VAR_INT, 2, NULL, NULL, NULL, NULL);
+	variable_add("contacts_groups", "cg", VAR_STR, 2, NULL, NULL, NULL, NULL);
+	variable_add("contacts_options", "cO", VAR_STR, 2, NULL, NULL, NULL, NULL);
+	variable_add("contacts_size", "cs", VAR_INT, 2, NULL, NULL, NULL, NULL);
 #endif
 	variable_add("dcc", "dc", VAR_BOOL, 1, &config_dcc, changed_dcc, NULL, NULL);
 	variable_add("dcc_ip", "di", VAR_STR, 1, &config_dcc_ip, changed_dcc, NULL, dd_dcc);
 	variable_add("dcc_dir", "dd", VAR_STR, 1, &config_dcc_dir, NULL, NULL, dd_dcc);
+	variable_add("dcc_backups", "db", VAR_BOOL, 1, &config_dcc_backups, NULL, NULL, dd_dcc);
+	variable_add("dcc_filter", "df", VAR_BOOL, 1, &config_dcc_filter, NULL, NULL, dd_dcc);
 	variable_add("dcc_limit", "dl", VAR_STR, 1, &config_dcc_limit, NULL, NULL, dd_dcc);
+	variable_add("dcc_port", "dP", VAR_INT, 1, &config_dcc_port, changed_dcc, NULL, dd_dcc);
 	variable_add("display_ack", "da", VAR_INT, 1, &config_display_ack, NULL, variable_map(4, 0, 0, "none", 1, 0, "all", 2, 0, "delivered", 3, 0, "queued"), NULL);
 	variable_add("display_color", "dC", VAR_INT, 1, &config_display_color, NULL, NULL, NULL);
 	variable_add("display_color_map", "dm", VAR_STR, 1, &config_display_color_map, NULL, NULL, dd_color);
 #ifdef WITH_UI_NCURSES
 	if (ui_init == ui_ncurses_init)
 		variable_add("display_crap", "dr", VAR_BOOL, 1, &config_display_crap, NULL, NULL, NULL);
+	else
+		variable_add("display_crap", "dr", VAR_BOOL, 2, NULL, NULL, NULL, NULL);
+#else
+	variable_add("display_crap", "dr", VAR_BOOL, 2, NULL, NULL, NULL, NULL);
 #endif
-	variable_add("display_notify", "dn", VAR_INT, 1, &config_display_notify, NULL, variable_map(3, 0, 0, "none", 1, 2, "all", 2, 1, "significant"), NULL);
+	variable_add("display_notify", "dn", VAR_MAP, 1, &config_display_notify, NULL, variable_map(4, 0, 0, "none", 1, 2, "all", 2, 1, "significant", 4, 0, "unknown"), NULL);
 	variable_add("display_pl_chars", "dp", VAR_BOOL, 1, &config_display_pl_chars, NULL, NULL, NULL);
 	variable_add("display_sent", "ds", VAR_BOOL, 1, &config_display_sent, NULL, NULL, NULL);
 #ifdef HAVE_LIBJPEG
 	variable_add("display_token", "dT", VAR_BOOL, 1, &config_display_token, NULL, NULL, NULL);
+#else
+	variable_add("display_token", "dT", VAR_BOOL, 2, NULL, NULL, NULL, NULL);
 #endif
 	variable_add("display_welcome", "dw", VAR_BOOL, 1, &config_display_welcome, NULL, NULL, NULL);
 #ifdef WITH_UI_NCURSES
 	if (ui_init == ui_ncurses_init)
 		variable_add("display_transparent", "dt", VAR_BOOL, 1, &config_display_transparent, NULL, NULL, NULL);
+	else
+		variable_add("display_transparent", "dt", VAR_BOOL, 2, NULL, NULL, NULL, NULL);
+#else
+	variable_add("display_transparent", "dt", VAR_BOOL, 2, NULL, NULL, NULL, NULL);
 #endif
 	variable_add("emoticons", "eM", VAR_BOOL, 1, &config_emoticons, NULL, NULL, NULL);
 #ifdef HAVE_OPENSSL
 	variable_add("encryption", "en", VAR_BOOL, 1, &config_encryption, NULL, NULL, NULL);
+#else
+	variable_add("encryption", "en", VAR_BOOL, 2, NULL, NULL, NULL, NULL);
 #endif
+	variable_add("era_omnix", "eO", VAR_BOOL, 1, &config_era_omnix, changed_era_omnix, NULL, NULL);
 #ifdef WITH_UI_NCURSES
 	if (ui_init == ui_ncurses_init)
 		variable_add("enter_scrolls", "es", VAR_BOOL, 1, &config_enter_scrolls, NULL, NULL, NULL);
+	else
+		variable_add("enter_scrolls", "es", VAR_BOOL, 2, NULL, NULL, NULL, NULL);
+#else
+	variable_add("enter_scrolls", "es", VAR_BOOL, 2, NULL,  NULL, NULL, NULL);
 #endif
 	variable_add("events_delay", "ev", VAR_INT, 1, &config_events_delay, NULL, NULL, NULL);
 #ifdef WITH_UI_NCURSES
 	if (ui_init == ui_ncurses_init)
 		variable_add("header_size", "hs", VAR_INT, 1, &config_header_size, header_statusbar_resize, NULL, NULL);
+	else
+		variable_add("header_size", "hs", VAR_INT, 2, NULL, NULL, NULL, NULL);
+#else
+	variable_add("header_size", "hs", VAR_INT, 2, NULL, NULL, NULL, NULL);
 #endif
 	variable_add("ignore_unknown_sender", "iu", VAR_BOOL, 1, &config_ignore_unknown_sender, NULL, NULL, NULL);
+	variable_add("ignore_empty_msg", "im", VAR_BOOL, 1, &config_ignore_empty_msg, NULL, NULL, NULL);
 	variable_add("keep_reason", "kr", VAR_INT, 1, &config_keep_reason, NULL, NULL, NULL);
 	variable_add("last", "la", VAR_MAP, 1, &config_last, NULL, variable_map(4, 0, 0, "none", 1, 2, "all", 2, 1, "separate", 4, 0, "sent"), NULL);
 	variable_add("last_size", "ls", VAR_INT, 1, &config_last_size, NULL, NULL, NULL);
 	variable_add("local_ip", "ld", VAR_STR, 1, &config_local_ip, changed_local_ip, NULL, NULL);
 	variable_add("log", "lo", VAR_MAP, 1, &config_log, NULL, variable_map(4, 0, 0, "none", 1, 2, "file", 2, 1, "dir", 4, 0, "gzip"), NULL);
 	variable_add("log_ignored", "li", VAR_INT, 1, &config_log_ignored, NULL, NULL, dd_log);
-	variable_add("log_status", "lS", VAR_BOOL, 1, &config_log_status, NULL, NULL, dd_log);
+	variable_add("log_status", "lS", VAR_INT, 1, &config_log_status, NULL, variable_map(3, 0, 0, "no", 1, 2, "yes", 2, 1, "descr"), dd_log);
 	variable_add("log_path", "lp", VAR_STR, 1, &config_log_path, NULL, NULL, dd_log);
 	variable_add("log_timestamp", "lt", VAR_STR, 1, &config_log_timestamp, NULL, NULL, dd_log);
 	variable_add("make_window", "mw", VAR_INT, 1, &config_make_window, NULL, variable_map(3, 0, 0, "none", 1, 2, "usefree", 2, 1, "always"), NULL);
@@ -216,13 +278,21 @@ void variable_init()
 	variable_add("sound_mail_file", "SM", VAR_STR, 1, &config_sound_mail_file, NULL, NULL, dd_sound);
 	variable_add("sound_app", "Sa", VAR_STR, 1, &config_sound_app, NULL, NULL, NULL);
 	variable_add("speech_app", "SA", VAR_STR, 1, &config_speech_app, NULL, NULL, NULL);
+	variable_add("status_window", "Sw", VAR_INT, 1, &config_status_window, NULL, variable_map(3, 0, 0, "query", 1, 2, "current", 2, 1, "status"), NULL);
 #ifdef WITH_UI_NCURSES
-	if (ui_init == ui_ncurses_init)
-	{
+	if (ui_init == ui_ncurses_init) {
 		variable_add("statusbar_size", "sS", VAR_INT, 1, &config_statusbar_size, header_statusbar_resize, NULL, NULL);
 		variable_add("statusbar_fgcolor", "sF", VAR_INT, 1, &config_statusbar_fgcolor, NULL, NULL, NULL);
 		variable_add("statusbar_bgcolor", "sB", VAR_INT, 1, &config_statusbar_bgcolor, NULL, NULL, NULL);
+	} else {
+		variable_add("statusbar_size", "sS", VAR_INT, 2, NULL, NULL, NULL, NULL);
+		variable_add("statusbar_fgcolor", "sF", VAR_INT, 2, NULL, NULL, NULL, NULL);
+		variable_add("statusbar_bgcolor", "sB", VAR_INT, 2, NULL, NULL, NULL, NULL);
 	}
+#else
+	variable_add("statusbar_size", "sS", VAR_INT, 2, NULL, NULL, NULL, NULL);
+	variable_add("statusbar_fgcolor", "sF", VAR_INT, 2, NULL, NULL, NULL, NULL);
+	variable_add("statusbar_bgcolor", "sB", VAR_INT, 2, NULL, NULL, NULL, NULL);
 #endif
 	variable_add("tab_command", "tc", VAR_STR, 1, &config_tab_command, NULL, NULL, NULL);
 	variable_add("theme", "th", VAR_STR, 1, &config_theme, changed_theme, NULL, NULL);
@@ -230,12 +300,20 @@ void variable_init()
 	variable_add("timestamp", "ts", VAR_STR, 1, &config_timestamp, NULL, NULL, NULL);
 #ifdef WITH_WAP
 	variable_add("wap_enabled", "we", VAR_INT, 1, &config_wap_enabled, NULL, NULL, NULL);
+#else
+	variable_add("wap_enabled", "we", VAR_INT, 2, NULL, NULL, NULL, NULL);
 #endif
 #ifdef WITH_UI_NCURSES
 	if (ui_init == ui_ncurses_init) {
-		variable_add("windows_save", "ws", VAR_BOOL, 1, &config_windows_save, NULL, NULL, NULL);
+		variable_add("windows_save", "ws", VAR_MAP, 1, &config_windows_save, NULL, variable_map(3, 0, 0, "no", 1, 0, "quit", 2, 0, "save"), NULL);
 		variable_add("windows_layout", "wl", VAR_STR, 2, &config_windows_layout, NULL, NULL, NULL);
+	} else {
+		variable_add("windows_save", "ws", VAR_MAP, 2, NULL, NULL, NULL, NULL);
+		variable_add("windows_layout", "wl", VAR_STR, 2, NULL, NULL, NULL, NULL);
 	}
+#else 
+	variable_add("windows_save", "ws", VAR_MAP, 2, NULL, NULL, NULL, NULL);
+	variable_add("windows_layout", "wl", VAR_STR, 2, NULL, NULL, NULL, NULL);
 #endif
 	variable_add("status", "st", VAR_INT, 2, &config_status, NULL, NULL, NULL);
 	variable_add("protocol", "pR", VAR_INT, 2, &config_protocol, NULL, NULL, NULL);
@@ -246,6 +324,9 @@ void variable_init()
 #ifdef WITH_IOCTLD
 	variable_add("ioctld_enable", "Ie", VAR_INT, 1, &config_ioctld_enable, NULL, NULL, NULL);
 	variable_add("ioctld_net_port", "Ip", VAR_INT, 1, &config_ioctld_net_port, NULL, NULL, NULL);
+#else
+	variable_add("ioctld_enable", "Ie", VAR_INT, 2, NULL, NULL, NULL, NULL);
+	variable_add("ioctld_net_port", "Ip", VAR_INT, 2, NULL, NULL, NULL, NULL);
 #endif
 }
 
@@ -293,6 +374,9 @@ struct variable *variable_find(const char *name)
 	for (l = variables; l; l = l->next) {
 		struct variable *v = l->data;
 
+		if (!v->ptr)
+			continue;
+
 		if (v->name_hash == hash && !strcasecmp(v->name, name))
 			return v;
 	}
@@ -569,7 +653,7 @@ void variable_free()
 
 		xfree(v->name);
 
-		if (v->type == VAR_STR) {
+		if (v->type == VAR_STR && v->ptr) {
 			xfree(*((char**) v->ptr));
 			*((char**) v->ptr) = NULL;
 		}
@@ -605,6 +689,9 @@ char *variable_digest()
 	for (l = variables; l; l = l->next) {
 		struct variable *v = l->data;
 
+		if (!v->ptr)
+			continue;
+
 		if ((v->type == VAR_INT || v->type == VAR_BOOL || v->type == VAR_MAP) && strcmp(v->name, "uin")) {
 			string_append(s, v->short_name);
 			string_append(s, itoa(*(int*)(v->ptr)));
@@ -615,6 +702,9 @@ char *variable_digest()
 		struct variable *v = l->data;
 		char *val;
 
+		if (!v->ptr)
+			continue;
+
 		if (!v->type == VAR_STR || !strcmp(v->name, "password") || !strcmp(v->name, "local_ip"))
 			continue;
 	
@@ -754,6 +844,11 @@ void variable_help(const char *name)
 	}
 
 	while ((line = read_file(f))) {
+		if (strlen(line) >= 2 && line[0] == '/' && line[1] == '/') {
+			xfree(line);
+			continue;
+		}
+
 		if (!strcasecmp(line, name)) {
 			found = 1;
 			xfree(line);
